@@ -2,18 +2,25 @@ from pathlib import Path
 
 import click
 
+from .assets import generate_assets
 from .config import (
+    DEFAULT_ASSETS_DIR,
     DEFAULT_DASHBOARDS_DIR,
     DEFAULT_RUNSERVER_FILE,
     DEFAULT_SETTINGS_FILE,
 )
 from .utils import valid_dir_name, validate_path_does_not_exist
 
-SETTINGS_CONTENT = """from dash_dashboards.app import DashboardApp, MenuGroup, MenuItem
+SETTINGS_CONTENT = """import pathlib
+
+from dash_dashboards.app import DashboardApp, MenuGroup, MenuItem
+
+ASSETS_DIR = (pathlib.Path(__file__).parent / "assets").resolve()
 
 app = DashboardApp(
     title="{project_name}",
     menu=[],
+    assets_folder=ASSETS_DIR,
 )
 """
 
@@ -24,6 +31,15 @@ from settings import app
 run_server(obj=app)
 """
 
+WSGI_CONTENT = """# !pip install -r requirements.txt
+
+import os
+
+from settings import app
+
+app.run_server(port=int(os.environ["CDSW_READONLY_PORT"]))
+"""
+
 
 @click.command(name="startproject")
 @click.option("-n", "--name", prompt="Project name", type=str, help="Project name.")
@@ -45,6 +61,8 @@ def start_project(name: str, dir_path: Path):
     settings_path = project_path / DEFAULT_SETTINGS_FILE
     runserver_file = project_path / DEFAULT_RUNSERVER_FILE
     dashboards_path = project_path / DEFAULT_DASHBOARDS_DIR
+    wsgi_file = project_path / "wsgi.py"
+    assets_path = project_path / DEFAULT_ASSETS_DIR
 
     dashboards_path.mkdir()
     with settings_path.open("w") as fp:
@@ -52,3 +70,8 @@ def start_project(name: str, dir_path: Path):
 
     with runserver_file.open("w") as fp:
         fp.writelines(RUNSERVER_CONTENT)
+
+    with wsgi_file.open("w") as fp:
+        fp.writelines(WSGI_CONTENT)
+
+    generate_assets(assets_path)
